==> rD3plot_1.0.25.tgz: rD3plot/www/ca.js <==
// texts to translate
var texts = {
    graph : "gràfic",
    nodes : "Nodes",
    general: "General",
    links: "Enllaços",
    apply: "Aplicar",
    filter: "Filtre",
    isolate: "Aïllar",
    select: "Escull",
    clear: "Net",
    add: "Afegeix",
    nodesattributes: "Atributs dels nodes",
    linksattributes: "Atributs dels enllaços",
    noitemsselected: "Selecciona un node en el gràfic per veure els atributs.",
    repulsion: "Repulsió",
    distance: "Distància",
    loading: "Carregant...",
    pdfexport: "PDF exportació",
    svgexport: "SVG exportació",
    pngexport: "PNG exportació",
    showHelp: "Mostrar ajuda",
    showhidelegend: "Llegenda",
    Image: "Imatge",
    showhideaxes: "Eixos",
    showhidesidebar: "Mostra/oculta barra lateral",
    showhidebuttons: "Mostra/oculta botons",
    showhidetables: "Mostra/oculta taules",
    stopresume: "Dinàmic",
    heatmap: "Heatmap",
    resetfilter: "Elimina els filtres",
    selectall: "Selecció tots",
    selectneighbors: "Afegir veïns",
    expand: "Expandir",
    collapse: "Contraure",
    Reverse: "Reverse",
    tableselection: "Marcats en la taula",
    reset: "Restaurar",
    directional: "Fletxes",
    degree: "Grau",
    none: "Cap",
    default: "Per defecte",
    downloadtable: "Descarrega la taula",
    total: "Total",
    concoincidences: "Coincidències condicionals",
    coincidences: "Coincidències",
    ofsomeone: "de",
    withsomeone: "amb",
    incidences: "Incidències",
    expected: "Esperades",
    expectedconfidence: "+/- Confiança esperada",
    confidenceinterval: "+/- Interval de confiança",
    subjectselect: "Esdeveniment",
    Label: "Etiqueta",
    LabelSize: "Gra.Eti.",
    Group: "Grup",
    Order: "Ordre",
    Size: "Grandària",
    Color: "Color",
    Shape: "Forma",
    Legend: "Llegenda",
    Width: "Amplitud",
    Weight: "Pes",
    Intensity: "Intensitat",
    Text: "Text",
    LabelInfo: "Label",
    LabelSizeInfo: "Label Size",
    GroupInfo: "Group",
    OrderInfo: "Order",
    SizeInfo: "Size",
    ColorInfo: "Color",
    ShapeInfo: "Shape",
    LegendInfo: "Legend",
    WidthInfo: "Width",
    WeightInfo: "Weight",
    IntensityInfo: "Intensity",
    TextInfo: "Text",
    Layout: "Disposició",
    LayoutInfo: "Disposició",
    Show: "Mostra",
    Hide: "Oculta",
    circle: "cercle",
    cross: "cruz",
    diamond: "diamante",
    square: "quadrat",
    "triangle-down": "triangle-avall",
    "triangle-up": "triangle-amunt",
    trianglesquare: "Triangle",
    selectacolorscale: "Selecciona una escala de color per ",
    selectacolor: "Selecciona un color per ",
    selectashape: "Selecciona una forma per ",
    selectattribute: "Selecciona un atribut per mostrar com a color ",
    outof: "de",
    scenarios: "nombre d'escenaris",
    resetzoom: "Restaurar zoom",
    zoomin: "Ampliar zoom",
    zoomout: "Disminuir zoom",
    removefilter: "Treure filtre",
    alertrecordheatmap: "el heatmap no es pot gravar.",
    speed: "Velocitat",
    searchanode: "Cerqueu un node",
    goback: "Tornar",
    newtab: "Obriu a la pestanya nova",
    tools: "Eines",
    poweredby: "Fet amb",
    isolateInfo: "Permet veure únicament el node (o nodes) seleccionat",
    filterInfo: "Permet veure el node (o nodes) seleccionat i la seva xarxa (nodes amb els quals està relacionat)",
    selectcustomcolor: "Selecciona un color personalitzat",
    filterselection: "Filtrar selecció",
    Elements: "Elements",
    Deselect: "Desmarcar",
    more: "més",
    less: "menys",
    Scale: "Escala"
  };

==> rD3plot_1.0.68.tgz: rD3plot/www/ca.js <==
// texts to translate
var texts = {
    graph : "gràfic",
    nodes : "Nodes",
    general: "General",
    links: "Enllaços",
    apply: "Aplicar",
    filter: "Filtre",
    isolate: "Aïllar",
    select: "Escull",
    clear: "Net",
    add: "Afegeix",
    nodesattributes: "Atributs dels nodes",
    linksattributes: "Atributs dels enllaços",
    elementsattributes: "Atributs dels elements",
    nonodesselected: "Selecciona un node en el gràfic per veure els atributs.",
    nolinksselected: "Selecciona un enllaç en el gràfic per veure els atributs.",
    noitemsselected: "Selecciona nodes o enllaços.",
    noelementsselected: "Selecciona elements en el gràfic per veure els atributs.",
    repulsion: "Repulsió",
    distance: "Distància",
    loading: "Carregant...",
    pdfexport: "PDF exportació",
    svgexport: "SVG exportació",
    pngexport: "PNG exportació",
    showHelp: "Mostrar ajuda",
    showhidelegend: "Llegenda",
    Image: "Imatge",
    showhideaxes: "Eixos",
    showhidesidebar: "Mostra/oculta barra lateral",
    showhidebuttons: "Mostra/oculta botons",
    showhidetables: "Mostra/oculta taules",
    stopresume: "Dinàmic",
    heatmap: "Heatmap",
    resetfilter: "Elimina els filtres",
    selectall: "Selecció tots",
    selectallnone: "Selecció tots / cap",
    selectneighbors: "Afegir veïns",
    expand: "Expandir",
    collapse: "Contraure",
    Reverse: "Reverse",
    tableselection: "Marcats en la taula",
    reset: "Restaurar",
    directional: "Fletxes",
    degree: "Grau",
    none: "Cap",
    default: "Per defecte",
    downloadtable: "Descarrega la taula",
    total: "Total",
    concoincidences: "Coincidències condicionals",
    coincidences: "Coincidències",
    ofsomeone: "de",
    withsomeone: "amb",
    incidences: "Incidències",
    expected: "Esperades",
    expectedconfidence: "+/- Confiança esperada",
    confidenceinterval: "+/- Interval de confiança",
    subjectselect: "Esdeveniment",
    Label: "Etiqueta",
    LabelSize: "Gra.Eti.",
    Group: "Grup",
    Border: "Vora",
    Order: "Ordre",
    Size: "Grandària",
    Color: "Color",
    Shape: "Forma",
    Legend: "Llegenda",
    Width: "Amplitud",
    Weight: "Pes",
    Intensity: "Intensitat",
    Text: "Text",
    LabelInfo: "Label",
    LabelSizeInfo: "Label Size",
    GroupInfo: "Group",
    BorderInfo: "Vora",
    OrderInfo: "Order",
    SizeInfo: "Size",
    ColorInfo: "Color",
    ShapeInfo: "Shape",
    LegendInfo: "Legend",
    WidthInfo: "Width",
    WeightInfo: "Weight",
    IntensityInfo: "Intensity",
    TextInfo: "Text",
    Layout: "Disposició",
    LayoutInfo: "Disposició",
    Show: "Mostra",
    Hide: "Oculta",
    circle: "cercle",
    cross: "cruz",
    diamond: "diamante",
    square: "quadrat",
    "triangle-down": "triangle-avall",
    "triangle-up": "triangle-amunt",
    trianglesquare: "Triangle",
    selectacolorscale: "Selecciona una escala de color per ",
    selectacolor: "Selecciona un color per ",
    selectashape: "Selecciona una forma per ",
    selectattribute: "Selecciona un atribut per mostrar com a ",
    outof: "de",
    scenarios: "nombre d'escenaris",
    resetzoom: "Restaurar zoom",
    zoomin: "Ampliar zoom",
    zoomout: "Disminuir zoom",
    removefilter: "Treure filtre",
    alertrecordheatmap: "el heatmap no es pot gravar.",
    speed: "Velocitat",
    searchintable: "Cerca a la taula ",
    goback: "Tornar",
    newtab: "Obriu a la pestanya nova",
    tools: "Eines",
    poweredby: "Fet amb",
    isolateInfo: "Permet veure únicament el node (o nodes) seleccionat",
    filterInfo: "Permet veure el node (o nodes) seleccionat i la seva xarxa (nodes amb els quals està relacionat)",
    selectcustomcolor: "Selecciona un color personalitzat",
    filterselection: "Filtrar selecció",
    Elements: "Elements",
    more: "més",
    less: "menys",
    Scale: "Escala",
    Table: "Taula",
    goto: "anar a",
    showonlyselecteditems: "Mostra només ítems seleccionats",
    Variable: "Variable",
    Value: "Valor",
    highlightneighbors: "Ressaltar veïns"
  };
